local style = require "core.style"
local common = require "core.common"

style.background = { common.color "#1E2326"}
style.background2 = { common.color "#1E2326"}
style.background3 = { common.color "#1E2326"}
style.text = { common.color "#D3C6AA"}
style.caret = { common.color "#A7C080"}
style.accent = { common.color "#A7C080"}
style.dim = { common.color "#859289"}
style.divider = { common.color "#272E33"}
style.selection = { common.color "#2E383C"}
style.line_number = {common.color "#2E383C"}
style.line_number2 = {common.color "#374145"}
style.line_highlight = {common.color "#272E33"}
style.scrollbar = { common.color "#4F5B58"}
style.scrollbar2 = { common.color "#4F5B58"}
style.scrollbar_track = { common.color "#272E33"}

style.syntax["normal"] = { common.color "#D3C6AA"}
style.syntax["symbol"] = { common.color "#D3C6AA"}
style.syntax["comment"] = {common.color "#4F5B58"}
style.syntax["keyword"] = {common.color "#E67E80"}
style.syntax["keyword2"] = {common.color "#E67E80"}
style.syntax["number"] = {common.color "#D699B6"}
style.syntax["literal"] = {common.color "#7FBBB3"}
style.syntax["string"] = {common.color "#83C092"}
style.syntax["operator"] = {common.color "#DBBC7F"}
style.syntax["function"] = {common.color "#A7C080"}

